@@ -7,8 +7,6 @@ from aioredis.commands.string import StringCommandsMixin
 from aioredis.commands.transaction import Pipeline, MultiExec
 from aioredis.errors import ReplyError, MaxClientsError, AuthError, ReadOnlyError
 
-from contextlib import asynccontextmanager
-
 from .base import Utils, WeakContextVar, AsyncContextManager, AsyncCirculator
 from .event import DistributedEvent
 from .ntp import NTPClient
@@ -43,7 +41,7 @@ class RedisPool:
 
         self._pool = yield from aioredis.create_pool(**self._settings).__await__()
 
-        Utils.log.info(f"Redis {self._settings[r'address']} initialized")
+        Utils.log.info(f"Redis {self._settings[r'address']} initialized: {self._pool.size}/{self._pool.maxsize}")
 
         return self
 
@@ -67,6 +65,11 @@ class RedisDelegate:
 
         self._cache_client_context = WeakContextVar(f'cache_client_{Utils.uuid1()}')
 
+    @property
+    def redis_pool(self):
+
+        return self._redis_pool
+
     async def async_init_redis(self, *args, **kwargs):
 
         self._redis_pool = await RedisPool(*args, **kwargs)
@@ -109,6 +112,10 @@ class RedisDelegate:
 
         return DistributedEvent(self._redis_pool, channel_name, channel_count)
 
+    def period_counter(self, time_slice: int, key_prefix: str = r'', ntp_client: NTPClient = None):
+
+        return PeriodCounter(self._redis_pool, time_slice, key_prefix, ntp_client)
+
 
 class CacheClient(aioredis.Redis, AsyncContextManager):
     """Redis客户端对象，使用with进行上下文管理
@@ -160,19 +167,6 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         await self._close_conn()
 
-    @asynccontextmanager
-    async def catch_error(self):
-
-        try:
-
-            yield
-
-        except Exception as err:
-
-            Utils.log.exception(err)
-
-            await self._close_conn(True)
-
     async def _safe_execute(self, func, *args, **kwargs):
 
         global REDIS_ERROR_RETRY_COUNT
@@ -189,21 +183,17 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
             except (ReplyError, MaxClientsError, AuthError, ReadOnlyError) as err:
 
-                Utils.log.exception(err)
-
                 await self._close_conn(True)
 
                 raise err
 
             except Exception as err:
 
-                # 记录异常，如果不重新尝试会继续抛出异常
-
-                Utils.log.exception(err)
-
                 await self._close_conn(True)
 
-                if times >= REDIS_ERROR_RETRY_COUNT:
+                if times < REDIS_ERROR_RETRY_COUNT:
+                    Utils.log.exception(err)
+                else:
                     raise err
 
             else:
@@ -252,11 +242,11 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
     def multi_exec(self):
 
-        return MultiExec(self._pool, aioredis.Redis, loop=self._pool._loop)
+        return MultiExec(self._pool, aioredis.Redis)
 
     def pipeline(self):
 
-        return Pipeline(self._pool, aioredis.Redis, loop=self._pool._loop)
+        return Pipeline(self._pool, aioredis.Redis)
 
     # PUB/SUB COMMANDS
 
@@ -300,34 +290,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return self._pool_or_conn.in_pubsub
 
-    # OVERRIDE COMMANDS
-
-    async def get(self, key):
-
-        result = await super().get(key)
-
-        if result is not None:
-            result = self._val_decode(result)
-
-        return result
-
-    def _get(self, key, *, encoding=_NOTSET):
-
-        return super().get(key, encoding=encoding)
-
-    async def set(self, key, value, expire=0):
-
-        _expire = expire if expire > 0 else self._expire
-
-        value = self._val_encode(value)
-
-        result = await super().set(key, value, expire=_expire)
-
-        return result
-
-    def _set(self, key, value, *, expire=0, pexpire=0, exist=None):
-
-        return super().set(key, value, expire=expire, pexpire=pexpire, exist=exist)
+    # GENERIC COMMANDS
 
     async def delete(self, *keys):
 
@@ -348,27 +311,406 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().delete(key, *keys)
 
-    # LIST COMMANDS
+    async def keys(self, pattern):
 
-    async def blpop(self, key, *keys, timeout=0, encoding=_NOTSET):
+        result = await super().keys(pattern)
 
-        result = await super().blpop(key, *keys, timeout=timeout, encoding=encoding)
+        if result is not None:
+            result = [Utils.basestring(key) for key in result]
+
+        return result
+
+    def _keys(self, pattern, *, encoding=_NOTSET):
+
+        return super().keys(pattern, encoding=encoding)
+
+    async def randomkey(self):
+
+        result = await super().randomkey()
+
+        if result is not None:
+            result = Utils.basestring(result)
+
+        return result
+
+    def _randomkey(self, *, encoding=_NOTSET):
+
+        return super().randomkey(encoding=encoding)
+
+    async def scan(self, cursor=0, match=None, count=None):
+
+        result = await super().scan(cursor, match, count)
+
+        if result is not None:
+            result = (result[0], [Utils.basestring(val) for val in result[1]])
+
+        return result
+
+    def _scan(self, cursor=0, match=None, count=None):
+
+        return super().scan(cursor, match, count)
+
+    # STRING COMMANDS
+
+    async def get(self, key):
+
+        result = await super().get(key)
+
+        if result is not None:
+            result = self._val_decode(result)
+
+        return result
+
+    def _get(self, key, *, encoding=_NOTSET):
+
+        return super().get(key, encoding=encoding)
+
+    async def getset(self, key, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().getset(key, _value)
+
+        if result is not None:
+            result = self._val_decode(result)
+
+        return result
+
+    def _getset(self, key, value, *, encoding=_NOTSET):
+
+        return super().getset(key, value, encoding=encoding)
+
+    async def mget(self, key, *keys):
+
+        result = await super().mget(key, *keys)
 
         if result is not None:
             result = [self._val_decode(val) for val in result]
 
         return result
 
+    def _mget(self, key, *keys, encoding=_NOTSET):
+
+        return super().mget(key, *keys, encoding=encoding)
+
+    async def set(self, key, value, expire=0):
+
+        _value = self._val_encode(value)
+        _expire = expire if expire > 0 else self._expire
+
+        result = await super().set(key, _value, expire=_expire)
+
+        return result
+
+    def _set(self, key, value, *, expire=0, pexpire=0, exist=None):
+
+        return super().set(key, value, expire=expire, pexpire=pexpire, exist=exist)
+
+    async def mset(self, key, value, *pairs):
+
+        _value = self._val_encode(value)
+        _pairs = [item if index % 2 == 0 else self._val_encode(item) for index, item in enumerate(pairs)]
+
+        result = await super().mset(key, _value, *_pairs)
+
+        return result
+
+    def _mset(self, key, value, *pairs):
+
+        return super().mset(key, value, *pairs)
+
+    async def msetnx(self, key, value, *pairs):
+
+        _value = self._val_encode(value)
+        _pairs = [item if index % 2 == 0 else self._val_encode(item) for index, item in enumerate(pairs)]
+
+        result = await super().msetnx(key, _value, *_pairs)
+
+        return result
+
+    def _msetnx(self, key, value, *pairs):
+
+        return super().msetnx(key, value, *pairs)
+
+    async def psetex(self, key, milliseconds, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().psetex(key, milliseconds, _value)
+
+        return result
+
+    def _psetex(self, key, milliseconds, value):
+
+        return super().psetex(key, milliseconds, value)
+
+    async def setex(self, key, seconds, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().setex(key, seconds, _value)
+
+        return result
+
+    def _setex(self, key, seconds, value):
+
+        return super().setex(key, seconds, value)
+
+    async def setnx(self, key, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().setnx(key, _value)
+
+        return result
+
+    def _setnx(self, key, value):
+
+        return super().setnx(key, value)
+
+    # SET COMMANDS
+
+    async def sdiff(self, key, *keys):
+
+        result = await super().sdiff(key, *keys)
+
+        if result is not None:
+            result = [Utils.basestring(val) for val in result]
+
+        return result
+
+    def _sdiff(self, key, *keys):
+
+        return super().sdiff(key, *keys)
+
+    async def sinter(self, key, *keys):
+
+        result = await super().sinter(key, *keys)
+
+        if result is not None:
+            result = [Utils.basestring(val) for val in result]
+
+        return result
+
+    def _sinter(self, key, *keys):
+
+        return super().sinter(key, *keys)
+
+    async def smembers(self, key):
+
+        result = await super().smembers(key)
+
+        if result is not None:
+            result = [Utils.basestring(val) for val in result]
+
+        return result
+
+    def _smembers(self, key, *, encoding=_NOTSET):
+
+        return super().smembers(key, encoding=encoding)
+
+    async def spop(self, key):
+
+        result = await super().spop(key)
+
+        if result is not None:
+            result = Utils.basestring(result)
+
+        return result
+
+    def _spop(self, key, *, encoding=_NOTSET):
+
+        return super().spop(key, encoding=encoding)
+
+    async def srandmember(self, key, count=1):
+
+        result = await super().srandmember(key, count)
+
+        if result is not None:
+            result = [Utils.basestring(val) for val in result]
+
+        return result
+
+    def _srandmember(self, key, count=None):
+
+        return super().srandmember(key, count)
+
+    async def sunion(self, key, *keys):
+
+        result = await super().sunion(key, *keys)
+
+        if result is not None:
+            result = [Utils.basestring(val) for val in result]
+
+        return result
+
+    def _sunion(self, key, *keys):
+
+        return super().sunion(key, *keys)
+
+    async def sscan(self, key, cursor=0, match=None, count=None):
+
+        result = await super().sscan(key, cursor, match, count)
+
+        if result is not None:
+            result = (result[0], [Utils.basestring(val) for val in result[1]])
+
+        return result
+
+    def _sscan(self, key, cursor=0, match=None, count=None):
+
+        return super().sscan(key, cursor, match, count)
+
+    # HASH COMMANDS
+
+    async def hget(self, key, field):
+
+        result = await super().hget(key, field)
+
+        if result is not None:
+            result = self._val_decode(result)
+
+        return result
+
+    def _hget(self, key, field, *, encoding=_NOTSET):
+
+        return super().hget(key, field, encoding=encoding)
+
+    async def hgetall(self, key):
+
+        result = await super().hgetall(key)
+
+        if result is not None:
+            result = {Utils.basestring(key): self._val_decode(val) for key, val in result.items()}
+
+        return result
+
+    def _hgetall(self, key, *, encoding=_NOTSET):
+
+        return super().hgetall(key, encoding=encoding)
+
+    async def hkeys(self, key):
+
+        result = await super().hkeys(key)
+
+        if result is not None:
+            result = [Utils.basestring(key) for key in result]
+
+        return result
+
+    def _hkeys(self, key, *, encoding=_NOTSET):
+
+        return super().hkeys(key, encoding=encoding)
+
+    async def hmget(self, key, field, *fields):
+
+        result = await super().hmget(key, field, *fields)
+
+        if result is not None:
+            result = [self._val_decode(val) for val in result]
+
+        return result
+
+    def _hmget(self, key, field, *fields, encoding=_NOTSET):
+
+        return super().hmget(key, field, *fields, encoding=encoding)
+
+    async def hmset(self, key, field, value, *pairs):
+
+        _value = self._val_encode(value)
+        _pairs = [item if index % 2 == 0 else self._val_encode(item) for index, item in enumerate(pairs)]
+
+        result = await super().hmset(key, field, _value, *_pairs)
+
+        return result
+
+    def _hmset(self, key, field, value, *pairs):
+
+        return super().hmset(key, field, value, *pairs)
+
+    async def hmset_dict(self, key, *args, **kwargs):
+
+        for _arg in args:
+            if isinstance(_arg, dict):
+                kwargs.update({key: self._val_encode(val) for key, val in _arg.items()})
+
+        return await super().hmset_dict(key, kwargs)
+
+    def _hmset_dict(self, key, *args, **kwargs):
+
+        return super().hmset_dict(key, *args, **kwargs)
+
+    async def hset(self, key, field, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().hset(key, field, _value)
+
+        return result
+
+    def _hset(self, key, field, value):
+
+        return super().hset(key, field, value)
+
+    async def hsetnx(self, key, field, value):
+
+        _value = self._val_encode(value)
+
+        result = await super().hsetnx(key, field, _value)
+
+        return result
+
+    def _hsetnx(self, key, field, value):
+
+        return super().hsetnx(key, field, value)
+
+    async def hvals(self, key):
+
+        result = await super().hvals(key)
+
+        if result is not None:
+            result = [self._val_decode(val) for val in result]
+
+        return result
+
+    def _hvals(self, key, *, encoding=_NOTSET):
+
+        return super().hvals(key, encoding=encoding)
+
+    async def hscan(self, key, cursor=0, match=None, count=None):
+
+        result = await super().hscan(key, cursor, match, count)
+
+        if result is not None:
+            result = (result[0], [(Utils.basestring(key), self._val_decode(val), ) for key, val in result[1]])
+
+        return result
+
+    def _hscan(self, key, cursor=0, match=None, count=None):
+
+        return super().hscan(key, cursor, match, count)
+
+    # LIST COMMANDS
+
+    async def blpop(self, key, *, timeout=0):
+
+        result = await super().blpop(key, timeout=timeout)
+
+        if result is not None:
+            result = self._val_decode(result[1])
+
+        return result
+
     def _blpop(self, key, *keys, timeout=0, encoding=_NOTSET):
 
         return super().blpop(key, *keys, timeout=timeout, encoding=encoding)
 
-    async def brpop(self, key, *keys, timeout=0, encoding=_NOTSET):
+    async def brpop(self, key, *, timeout=0):
 
-        result = await super().brpop(key, *keys, timeout=timeout, encoding=encoding)
+        result = await super().brpop(key, timeout=timeout)
 
         if result is not None:
-            result = [self._val_decode(val) for val in result]
+            result = self._val_decode(result[1])
 
         return result
 
@@ -376,9 +718,9 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().brpop(key, *keys, timeout=timeout, encoding=encoding)
 
-    async def brpoplpush(self, sourcekey, destkey, timeout=0, encoding=_NOTSET):
+    async def brpoplpush(self, sourcekey, destkey, timeout=0):
 
-        result = await super().brpoplpush(sourcekey, destkey, timeout, encoding)
+        result = await super().brpoplpush(sourcekey, destkey, timeout)
 
         if result is not None:
             result = self._val_decode(result)
@@ -389,7 +731,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().brpoplpush(sourcekey, destkey, timeout, encoding)
 
-    async def lindex(self, key, index, *, encoding=_NOTSET):
+    async def lindex(self, key, index):
 
         result = await super().lindex(key, index, encoding=encoding)
 
@@ -415,9 +757,9 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().linsert(key, pivot, value, before=before)
 
-    async def lpop(self, key, *, encoding=_NOTSET):
+    async def lpop(self, key):
 
-        result = await super().lpop(key, encoding=encoding)
+        result = await super().lpop(key)
 
         if result is not None:
             result = self._val_decode(result)
@@ -453,9 +795,9 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().lpushx(key, value)
 
-    async def lrange(self, key, start, stop, *, encoding=_NOTSET):
+    async def lrange(self, key, start, stop):
 
-        result = await super().lrange(key, start, stop, encoding=encoding)
+        result = await super().lrange(key, start, stop)
 
         if result is not None:
             result = [self._val_decode(val) for val in result]
@@ -490,22 +832,9 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().lset(key, index, value)
 
-    async def ltrim(self, key, start, stop):
+    async def rpop(self, key):
 
-        result = await super().ltrim(key, start, stop)
-
-        if result is not None:
-            result = [self._val_decode(val) for val in result]
-
-        return result
-
-    def _ltrim(self, key, start, stop):
-
-        return super().ltrim(key, start, stop)
-
-    async def rpop(self, key, *, encoding=_NOTSET):
-
-        result = await super().rpop(self, key, encoding=encoding)
+        result = await super().rpop(key)
 
         if result is not None:
             result = self._val_decode(result)
@@ -516,9 +845,9 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
         return super().rpop(self, key, encoding=encoding)
 
-    async def rpoplpush(self, sourcekey, destkey, *, encoding=_NOTSET):
+    async def rpoplpush(self, sourcekey, destkey):
 
-        result = await super().rpoplpush(self, sourcekey, destkey, encoding=encoding)
+        result = await super().rpoplpush(sourcekey, destkey)
 
         if result is not None:
             result = self._val_decode(result)
@@ -527,7 +856,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
     def _rpoplpush(self, sourcekey, destkey, *, encoding=_NOTSET):
 
-        return super().rpoplpush(self, sourcekey, destkey, encoding=encoding)
+        return super().rpoplpush(sourcekey, destkey, encoding=encoding)
 
     async def rpush(self, key, value, *values):
 
@@ -540,10 +869,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
     def _rpush(self, key, value, *values):
 
-        _value = self._val_encode(value)
-        _values = [self._val_encode(val) for val in values]
-
-        return super().rpush(key, _value, *_values)
+        return super().rpush(key, value, *values)
 
     async def rpushx(self, key, value):
 
@@ -555,9 +881,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
 
     def _rpushx(self, key, value):
 
-        _value = self._val_encode(value)
-
-        return super().rpushx(key, _value)
+        return super().rpushx(key, value)
 
 
 class MLock(AsyncContextManager):
@@ -717,17 +1041,20 @@ class PeriodCounter:
 
     MIN_EXPIRE = 60
 
-    def __init__(self, ntp_client: NTPClient, cache_pool: RedisPool, time_slice: int, key_prefix: str = r''):
+    def __init__(self, cache_pool: RedisPool, time_slice: int, key_prefix: str = r'', ntp_client: NTPClient = None):
 
-        self._ntp_client = ntp_client
         self._cache_pool = cache_pool
 
         self._time_slice = time_slice
         self._key_prefix = key_prefix
 
+        self._ntp_client = ntp_client
+
     def _get_key(self, key: str = None) -> str:
 
-        time_period = Utils.math.floor(self._ntp_client.timestamp / self._time_slice)
+        timestamp = Utils.timestamp() if self._ntp_client is None else self._ntp_client.timestamp
+
+        time_period = Utils.math.floor(timestamp / self._time_slice)
 
         if key is None:
             return f'{self._key_prefix}_{time_period}'
