@@ -115,6 +115,11 @@ class MongoDelegate:
 
         self._mongo_pool = MongoPool(*args, **kwargs)
 
+    @property
+    def mongo_pool(self):
+
+        return self._mongo_pool
+
     async def mongo_health(self):
 
         result = False
@@ -319,6 +324,16 @@ class MySQLDelegate:
         self._mysql_rw_client_context = WeakContextVar(f'mysql_rw_client_{context_uuid}')
         self._mysql_ro_client_context = WeakContextVar(f'mysql_ro_client_{context_uuid}')
 
+    @property
+    def mysql_rw_pool(self):
+
+        return self._mysql_rw_pool
+
+    @property
+    def mysql_ro_pool(self):
+
+        return self._mysql_ro_pool
+
     async def async_init_mysql_rw(self, *args, **kwargs):
 
         self._mysql_rw_pool = await MySQLPool(*args, **kwargs)
@@ -623,21 +638,17 @@ class DBClient(_ClientBase, AsyncContextManager):
 
                 except (Warning, DataError, IntegrityError, ProgrammingError) as err:
 
-                    Utils.log.exception(err)
-
                     await self._close_conn(True)
 
                     raise err
 
                 except Exception as err:
 
-                    # 记录异常，如果不重新尝试会继续抛出异常
-
-                    Utils.log.exception(err)
-
                     await self._close_conn(True)
 
-                    if times >= MYSQL_ERROR_RETRY_COUNT:
+                    if times < MYSQL_ERROR_RETRY_COUNT:
+                        Utils.log.exception(err)
+                    else:
                         raise err
 
                 else:
@@ -693,8 +704,6 @@ class DBTransaction(DBClient):
 
             except Exception as err:
 
-                Utils.log.exception(err)
-
                 await self._close_conn(True)
 
                 raise err
