@@ -26,6 +26,7 @@ def json_wraps(func):
 
     @functools.wraps(func)
     async def _wrapper(handler, *args, **kwargs):
+
         resp = await Utils.awaitable_wrapper(
             func(handler, *args, **kwargs)
         )
@@ -153,6 +154,7 @@ class DebugHeader:
 class LogRequestMixin:
 
     def log_request(self):
+
         Utils.log.info(
             '\n---------- request arguments ----------\n' +
             json.dumps(
@@ -171,76 +173,88 @@ class _BaseHandlerMixin(Utils):
 
     @property
     def request_module(self):
+
         return f'{self.module}.{self.method}'
 
     @property
     def module(self):
+
         _class = self.__class__
 
         return f'{_class.__module__}.{_class.__name__}'
 
     @property
     def method(self):
+
         return self.request.method.lower()
 
     @property
     def version(self):
+
         return self.request.version.lower()
 
     @property
     def protocol(self):
+
         return self.request.protocol
 
     @property
     def host(self):
+
         return self.request.host
 
     @property
     def path(self):
+
         return self.request.path
 
     @property
     def query(self):
+
         return self.request.query
 
     @property
     def body(self):
+
         return self.request.body
 
     @property
     def files(self):
+
         return self.request.files
 
-    @property
-    def closed(self):
-        return self.request.connection.stream.closed()
-
     @property
     def referer(self):
+
         return self.get_header(r'Referer', r'')
 
     @property
     def client_ip(self):
+
         return self.get_header(r'X-Real-IP', self.request.remote_ip)
 
     @property
     def content_type(self):
+
         return self.get_header(r'Content-Type', r'')
 
     @property
     def content_length(self):
+
         result = self.get_header(r'Content-Length', r'')
 
         return int(result) if result.isdigit() else 0
 
     @property
     def headers(self):
+
         return self.request.headers
 
     def get_header(self, name, default=None):
         """
         获取header数据
         """
+
         return self.request.headers.get(name, default)
 
 
@@ -248,14 +262,13 @@ class SocketBaseHandler(WebSocketHandler, _BaseHandlerMixin):
     """WebSocket请求处理类
     """
 
-    def initialize(self, **kwargs):
-        setattr(self, r'_payload', kwargs)
-
     @property
-    def payload(self):
-        return getattr(self, r'_payload', None)
+    def closed(self):
+
+        return self.ws_connection is None
 
     def check_origin(self, origin):
+
         return True
 
 
@@ -272,6 +285,11 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
 
         return getattr(self, r'_payload', None)
 
+    @property
+    def closed(self):
+
+        return self.request.connection.stream.closed()
+
     def head(self, *_1, **_2):
 
         self.finish()
@@ -379,6 +397,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         获取files数据
         """
+
         result = []
 
         file_data = self.files.get(name, None)
@@ -399,6 +418,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         获取str型输入
         """
+
         result = self.get_argument(name, None, True)
 
         if result is None:
@@ -416,6 +436,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         获取bool型输入
         """
+
         result = self.get_argument(name, None, True)
 
         if result is None:
@@ -429,6 +450,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         获取int型输入
         """
+
         result = self.get_argument(name, None, True)
 
         if result is None:
@@ -443,6 +465,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         获取float型输入
         """
+
         result = self.get_argument(name, None, True)
 
         if result is None:
@@ -491,6 +514,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         输出JSON类型
         """
+
         self.set_header(r'Content-Type', r'application/json')
 
         if status_code != 200:
@@ -509,6 +533,7 @@ class RequestBaseHandler(RequestHandler, _BaseHandlerMixin):
         """
         输出PNG类型
         """
+
         self.set_header(r'Content-Type', r'image/png')
 
         return self.finish(chunk)
@@ -592,7 +617,7 @@ class DownloadAgent(RequestBaseHandler, DownloadBuffer):
 
         except Exception as err:
 
-            self.log.exception(err)
+            self.log.error(err)
 
         finally:
 
